@@ -1,8 +1,6 @@
 # -*- encoding=utf-8 -*-
 "Beam-like behaviour with cylinderConnections for roots interaction with spheres."
-from __future__ import print_function
 
-from builtins import range
 from yade import pack
 from yade.gridpfacet import *
 
