@@ -1,8 +1,6 @@
 # -*- encoding=utf-8 -*-
 """ Playground for tuning collider strides depending on maximum velocity. """
-from __future__ import print_function
 
-from builtins import range
 from yade import timing
 import os.path
 loadFrom = '/tmp/triax.xml'
