@@ -1,8 +1,5 @@
 # -*- encoding=utf-8 -*-
 
-from __future__ import print_function
-
-from builtins import range
 from yade import pack, export, geom, timing, bodiesHandling
 import time, numpy
 
