@@ -1,7 +1,3 @@
-from __future__ import print_function
-
-from builtins import range
-from builtins import object
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from PyQt4 import QtGui
