@@ -116,8 +116,8 @@ py::tuple bodyNumInteractionsHistogram(py::tuple aabb)
 	int maxIntr = 0;
 	for (const auto& i : *rb->interactions) {
 		if (!i->isReal()) continue;
-		const Body::id_t       id1 = i->getId1(), id2 = i->getId2();
-		const auto b1 = Body::byId(id1, rb), b2 = Body::byId(id2, rb);
+		const Body::id_t id1 = i->getId1(), id2 = i->getId2();
+		const auto       b1 = Body::byId(id1, rb), b2 = Body::byId(id2, rb);
 		if ((useBB && Shop::isInBB(b1->state->pos, bbMin, bbMax)) || !useBB) {
 			if (b1->isClumpMember()) bodyNumIntr[b1->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
 			else
@@ -278,7 +278,7 @@ void wireNoSpheres() { wireSome("noSpheres"); }
  * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
  *   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimers.
  *   2. Redistributions in binary form must reproduce the above copyright notice in the documentation and/or other materials provided with the distribution.
- *   3. The name of W. Randolph Franklin may not be used to endorse or promote products derived from this Software without specific prior written permission. 
+ *   3. The name of W. Randolph Franklin may not be used to endorse or promote products derived from this Software without specific prior written permission.
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  * http://numpy.scipy.org/numpydoc/numpy-13.html told me how to use Numeric.array from c
@@ -288,10 +288,15 @@ bool pointInsidePolygon(py::tuple xy, py::object vertices)
 	Real           testx = py::extract<Real>(xy[0])(), testy = py::extract<Real>(xy[1])();
 	char**         vertData;
 	int            rows, cols;
+	if (PyArray_API == NULL) import_array();
+	if (!PyArray_Check(vertices.ptr())) throw invalid_argument("Vertices must be a NumPy array");
 	PyArrayObject* vert   = (PyArrayObject*)vertices.ptr();
-	int            result = PyArray_As2D((PyObject**)&vert /* is replaced */, &vertData, &rows, &cols, PyArray_DOUBLE);
-	if (result != 0) throw invalid_argument("Unable to cast vertices to 2d array");
+	if (PyArray_NDIM(vert) != 2) throw invalid_argument("Input array must be 2-dimensional");
+	npy_intp dims[2] = { PyArray_DIM(vert, 0), PyArray_DIM(vert, 1) };
+	rows = (int)dims[0], cols = (int)dims[1];
 	if (cols != 2 || rows < 3) throw invalid_argument("Vertices must have 2 columns (x and y) and at least 3 rows.");
+	int result = PyArray_AsCArray((PyObject**)&vert /* is replaced */, (void**)&vertData, dims, 2, PyArray_DescrFromType(NPY_DOUBLE));
+	if (result < 0) throw invalid_argument("Unable to cast vertices to 2d array");
 	int  i /*current node*/, j /*previous node*/;
 	bool inside = false;
 	for (i = 0, j = rows - 1; i < rows; j = i++) {
@@ -299,7 +304,7 @@ bool pointInsidePolygon(py::tuple xy, py::object vertices)
 		       vx_j = *(double*)(vert->data + j * vert->strides[0]), vy_j = *(double*)(vert->data + j * vert->strides[0] + vert->strides[1]);
 		if (((vy_i > testy) != (vy_j > testy)) && (testx < (vx_j - vx_i) * (testy - vy_i) / (vy_j - vy_i) + vx_i)) inside = !inside;
 	}
-	Py_DECREF(vert);
+	PyArray_Free((PyObject*)vert, (void*)vertData);
 	return inside;
 }
 
@@ -590,7 +595,7 @@ try {
 	py::def("initMPI", initMPI, "Initialize MPI communicator, for Foam Coupling");
 	py::def("PWaveTimeStep",
 	        PWaveTimeStep,
-	        "Get timestep accoring to the velocity of P-Wave propagation; computed from sphere radii, rigidities and masses.");
+	        "Get timestep accoring to the velocity of P-Wave propagation; computed for spheres and/or polyhedra based on their sizes, rigidities and masses.");
 	py::def("RayleighWaveTimeStep", RayleighWaveTimeStep, "Determination of time step according to Rayleigh wave speed of force propagation.");
 	py::def("getSpheresVolume",
 	        Shop__getSpheresVolume,
@@ -817,9 +822,9 @@ try {
 	         py::args("nCell"),
 	         py::args("dz"),
 	         py::args("zRef"),
-	         py::args("activateCond"),
-	         py::args("radiusPy"),
-	         py::args("direction")),
+	         py::args("activateCond") = false,
+	         py::args("radiusPy")     = 0,
+	         py::args("direction")    = 2),
 	        "Compute and return the particle velocity and solid volume fraction (porosity) depth profile along the direction specified (default is z; "
 	        "0=>x,1=>y,2=>z). For each defined cell z, the k component of the average particle velocity reads: \n\n $<v_k>^z= \\sum_p V^p v_k^p/\\sum_p "
 	        "V^p$,\n\nwhere the sum is made over the particles contained in the cell, $v_k^p$ is the k component of the velocity associated to particle p, "
@@ -832,8 +837,46 @@ try {
 	        "activateCond is set to true, do the average only on particles of radius equal to radiusPy (input parameter)");
 	py::def("getDepthProfiles_center",
 	        Shop::getDepthProfiles_center,
-	        (py::args("volume"), py::args("nCell"), py::args("dz"), py::args("zRef"), py::args("activateCond"), py::args("radiusPy")),
+	        (py::args("volume"), py::args("nCell"), py::args("dz"), py::args("zRef"), py::args("activateCond") = false, py::args("radiusPy") = 0),
 	        "Same as getDepthProfiles but taking into account particles as points located at the particle center.");
+	py::def("getSlicedProfiles",
+	        Shop::getSlicedProfiles,
+	        (py::args("vCell"),
+	         py::args("nCell"),
+	         py::args("dP"),
+	         py::args("sliceCenters"),
+	         py::args("sliceWidths"),
+	         py::args("refP"),
+	         py::args("refS"),
+	         py::args("dirP")         = 2,
+	         py::args("dirS")         = 1,
+	         py::args("activateCond") = false,
+	         py::args("radiusPy")     = 0,
+	         py::args("nSimpson")     = 50),
+	        "Compute and return the particle solid volume fraction (porosity) and velocity profiles along a specific direction dirP and for a given "
+	        "subdomain. "
+	        "In the direction dirP, the subdomain is divided into nCell of size dP. For each cell, the averaged solid volume fraction reads: "
+	        "\n\n$<\\phi>= \\frac{1}{V_{cell}}\\sum_p V^p$\n\n and the averaged particle velocity reads: \n\n $<v_k>= \\sum_p V^p v_k^p/\\sum_p V^p$,\n\n "
+	        "where the sum is made over the particles p contained in the cell, $v_k^p$ is the k component of the velocity associated to particle p, $V^p$ "
+	        "is "
+	        "the part of the volume of the particle p contained inside the cell, and $V_{cell}$ is the volume of the cell (all subdomain slices combined). "
+	        "The volume of the sliced particle $V^p$ is computed analytically when the particle is not sliced by the subdomain boundaries. Otherwise, "
+	        "$V^p$ is computed using a Simpson integration of the sliced area of the sliced sphere.\n"
+	        "This function allows to define a discontinuous subdomain made of different slices in direction dirS. This can be useful to exclude specific "
+	        "zones "
+	        "from the averaging procedure or to target similar zones like symmetric boundaries.\n\n"
+	        "Arguments are:\n"
+	        "vCell : volume of a cell, all slices combined. (e.g. dP*length*(slicewidth1+slicewidth2))\n"
+	        "nCell : number of cells in the profile direction\n"
+	        "dP : discretisation interval in the Profile direction,\n"
+	        "sliceCenters : array containing the position of the center of each slice from refS in the S direction,\n"
+	        "sliceWidths : array containing the width of each slice,\n"
+	        "refP : reference position in the Profile direction,\n"
+	        "refS : reference position in the slice direction,\n"
+	        "dirP : direction of the profile (0:x, 1:y, 2:z), (default:2),\n"
+	        "dirS : direction of the slices (0:x, 1:y, 2:z), must be different from dirP, (default:1),\n"
+	        "activateCond : if true, will only consider particle of radius equal radiusPy, (default:false),\n"
+	        "nSimpson : number of intervals per particle radius for the Simpson integration, (default:50),\n");
 	py::def("getCapillaryStress",
 	        Shop::getCapillaryStress,
 	        (py::args("volume") = 0, py::args("mindlin") = false),
